@@ -29,9 +29,9 @@ static Widget tacho;
 static double speedfactor;
 static Widget toplevel;
 
-static void update_display(char *buf UNUSED)
+static void update_display(struct gps_data_t *gpsdata, char *buf UNUSED)
 {
-    TachometerSetValue(tacho, rint(gpsdata->speed * speedfactor));
+    TachometerSetValue(tacho, rint(gpsdata->fix.speed * speedfactor));
 }
 
 static void handle_input(XtPointer client_data UNUSED,
